..
  Lukas: Another draft
=====
Results
=====

RiboMetric has four different output formats:

* HTML: 
  The main output format is HTML, which includes interactive plots for different quality control metrics.

* PDF: 
  An alternative is PDF output, which is based on the HTML lay-out, but uses static images for the plots.  

* JSON: 
  This format contains all the results created by RiboMetric before they are used to create plots. This also includes the config that was used to achieve these results.
 
* CSV: 
  The CSV format only contains the scores for the different tested metrics and can be used to quickly compare multiple samples based on these scores.
  
Examples for each output format can be found on the `RiboMetric github <https://github.com/JackCurragh/RiboMetric>`_ under example-reports
